# Owl2diagram

## How to run locally
```
python 
```

## How to use

   `python -m owl2diagram "https://dgarijo.github.io/example/release/1.0.1/ontology.ttl" output.md`


## Example

## Version

```
0.1.0
```

## Authors

- Jhon Toledo.
